==> haystack-0.4.19.tar.gz: lib/src/HList.dart <==
import 'dart:collection';
import 'package:collection/collection.dart';
import 'HVal.dart';

/**
 * HList is an immutable list of HVal items.
 */
class HList extends HVal with ListMixin<HVal> {

//////////////////////////////////////////////////////////////////////////
// Constructor
//////////////////////////////////////////////////////////////////////////

  static final HList EMPTY = new HList([]);

  /** Create a list of the given items. The items are copied */
  factory HList(Iterable<HVal> items) =>
    new HList._(new List.from(items));

  HList._(this._items);

//////////////////////////////////////////////////////////////////////////
// Access
//////////////////////////////////////////////////////////////////////////

  @override
  int get length => _items.length;
  @override
  set length(int newLength) {
    throw new UnsupportedError("HList.length=");
  }

  @override
  HVal operator [](int index) => _items[index];

  @override
  void operator []=(int index, HVal value) {
    throw new UnsupportedError("HList.[]=");
  }

  /** Get the number of items in the list */
  int get size => _items.length;

  @override
  int get hashCode => new ListEquality().hash(_items);

  /** Get the HVal at the given index */
  HVal get(int i) => _items[i];

//////////////////////////////////////////////////////////////////////////
// HVal
//////////////////////////////////////////////////////////////////////////

  @override
  String toZinc() {
    StringBuffer s = new StringBuffer();
    s.write('[');
    s.write( _items.map((i) => i.toZinc()).join(",") );
    s.write(']');
    return s.toString();
  }

  @override
  String toJson() {
    throw new UnsupportedError("HList.toJson");
  }

  @override
  bool operator==(Object o) {
    if (o == null || runtimeType != o.runtimeType) return false;

    return new ListEquality().equals(_items, (o as HList)._items);
  }

//////////////////////////////////////////////////////////////////////////
// Fields
//////////////////////////////////////////////////////////////////////////

  final List<HVal> _items;
}

==> haystack-0.6.1.tar.gz: lib/src/HList.dart <==
///
/// Copyright (c) 2018, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

library haystack.hlist;

import 'dart:collection';

import 'package:collection/collection.dart';

import 'HVal.dart';

/// HList is an immutable list of HVal items.
class HList extends HVal with ListMixin<HVal> {
//////////////////////////////////////////////////////////////////////////
// Constructor
//////////////////////////////////////////////////////////////////////////

  static final HList EMPTY = new HList([]);

  /// Create a list of the given items. The items are copied
  factory HList(Iterable<HVal> items) => new HList._(new List.from(items));

  HList._(this._items);

//////////////////////////////////////////////////////////////////////////
// Access
//////////////////////////////////////////////////////////////////////////

  @override
  int get length => _items.length;
  @override
  set length(int newLength) {
    throw new UnsupportedError("HList.length=");
  }

  @override
  HVal operator [](int index) => _items[index];

  @override
  void operator []=(int index, HVal value) {
    throw new UnsupportedError("HList.[]=");
  }

  /// Get the number of items in the list
  int get size => _items.length;

  @override
  int get hashCode => new ListEquality<HVal>().hash(_items);

  /// Get the HVal at the given index
  HVal get(int i) => _items[i];

//////////////////////////////////////////////////////////////////////////
// HVal
//////////////////////////////////////////////////////////////////////////

  @override
  String toZinc() {
    StringBuffer s = new StringBuffer();
    s.write('[');
    s.write(_items.map((i) => i.toZinc()).join(","));
    s.write(']');
    return s.toString();
  }

  @override
  String toJson() {
    throw new UnsupportedError("HList.toJson");
  }

  @override
  bool operator ==(Object o) {
    if (o == null || runtimeType != o.runtimeType) return false;

    return new ListEquality<HVal>().equals(_items, (o as HList)._items);
  }

//////////////////////////////////////////////////////////////////////////
// Fields
//////////////////////////////////////////////////////////////////////////

  final List<HVal> _items;
}
